@@ -1,4 +1,4 @@
-/* $Id: gdict-about.c,v 1.7 2002/02/03 22:22:55 chyla Exp $ */
+/* $Id: gdict-about.c,v 1.11 2002/06/01 21:32:46 gman Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -26,6 +26,10 @@
 
 static GtkWidget *gdict_about_new (void)
 {
+    GdkPixbuf   *pixbuf;
+    GError  	*error = NULL;
+    gchar 	*file;
+    
     const gchar *authors[] = {
         "Mike Hughes <mfh@psilord.com>",
         "Spiros Papadimitriou <spapadim+@cs.cmu.edu>",
@@ -39,6 +43,16 @@ static GtkWidget *gdict_about_new (void)
     gchar *translator_credits = _("translator_credits");
     GtkWidget *about;
     
+    file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gdict.png", FALSE, NULL);
+    pixbuf = gdk_pixbuf_new_from_file (file, &error);
+    
+    if (error) {
+    	   g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+	   g_error_free (error);	
+    }
+    
+    g_free (file);    
+    
     about = gnome_about_new ("GNOME Dictionary", VERSION,
                              "Copyright 1999 by Mike Hughes",
                              _("Client for MIT dictionary server.\n"
@@ -47,15 +61,22 @@ static GtkWidget *gdict_about_new (void)
 			     (const char **)authors,
 			     (const char **)documenters,
 			     strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-                             NULL);
-    gtk_window_set_modal (GTK_WINDOW (about), TRUE);
+                             pixbuf);
+    if (pixbuf) {
+    	   gdk_pixbuf_unref (pixbuf);
+    }
+
+    gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/gdict.png");				     
+			     
     return about;
 }
 
-void gdict_about (void)
+void gdict_about (GtkWindow *parent)
 {
     GtkWidget *about = gdict_about_new();
-
+    if (parent) {
+      gtk_window_set_transient_for (GTK_WINDOW (about), parent) ;
+    }
     gtk_widget_show(about);
 }
 
