@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.34 2002/05/10 18:18:29 gman Exp $ */
+/* $Id: gdict-applet.c,v 1.37 2002/06/01 21:32:46 gman Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -125,14 +125,18 @@ button_press_cb (GtkButton *button, gpointer data)
 	
 }
 
+/* This is a hack around the fact that gtk+ doesn't
+ * propogate button presses on button2/3.
+ */
 static gboolean 
 button_press_hack (GtkWidget *w, GdkEventButton *event, gpointer data)
 {
-    PanelApplet *applet = PANEL_APPLET (data);
-    /* Pass the right click to the PanelApplet */
-    if (event->button == 3) {
-    	GTK_WIDGET_CLASS (PANEL_APPLET_GET_CLASS (applet))->
-			  button_press_event (data, event);
+    GtkWidget *applet = GTK_WIDGET (data);
+    
+    if (event->button == 3 || event->button == 2) {
+	event->window = applet->window;
+	gtk_main_do_event ((GdkEvent *) event);
+
 	return TRUE;
     }
     
@@ -155,7 +159,7 @@ about_cb (BonoboUIComponent *uic,
           gpointer           user_data,
           const gchar       *verbname)
 {
-	gdict_about();
+	gdict_about(NULL);
 }
 
 static void
@@ -222,6 +226,7 @@ gdict_applet_new (PanelApplet *parent_applet)
 {
 	GDictApplet *applet;
  	GtkWidget *hbox;
+
  	static GtkTargetEntry drop_targets [] = {
     		{ "UTF8_STRING", 0, 0 },
   		{ "COMPOUND_TEXT", 0, 0 },
@@ -237,14 +242,16 @@ gdict_applet_new (PanelApplet *parent_applet)
 	hbox = gtk_hbox_new (FALSE, 0);
 
 	applet->button_widget = gtk_button_new_with_mnemonic (_("_Lookup"));
+
 	gtk_drag_dest_set (applet->button_widget, GTK_DEST_DEFAULT_ALL, drop_targets, 
     		           G_N_ELEMENTS (drop_targets), GDK_ACTION_COPY | GDK_ACTION_MOVE);
-	gtk_box_pack_start (GTK_BOX (hbox), applet->button_widget, FALSE, FALSE, 2);
+	gtk_box_pack_end (GTK_BOX (hbox), applet->button_widget, FALSE, FALSE, 2);
 	
         if (GTK_IS_ACCESSIBLE (gtk_widget_get_accessible (applet->button_widget)))          
-        add_atk_namedesc (GTK_WIDGET (applet->button_widget), _("Dictionary Applet"), NULL);
+        add_atk_namedesc (GTK_WIDGET (applet->button_widget), _("Dictionary Lookup"), NULL);
 
 	applet->entry_widget = gtk_entry_new ();
+	gtk_entry_set_width_chars (GTK_ENTRY (applet->entry_widget), 12);
  	gtk_box_pack_start (GTK_BOX (hbox), applet->entry_widget, TRUE, TRUE, 0);
  	
  	gtk_widget_show_all (hbox);
