@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.27 2002/02/02 21:32:31 kevinv Exp $ */
+/* $Id: main.c,v 1.31 2002/04/26 01:33:02 gman Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -51,30 +51,34 @@ static gint save_yourself_cb (GnomeClient       *client,
     return TRUE;
 }
 
+static gint client_die_cb (GnomeClient *client, gpointer client_data)
+{
+	gtk_main_quit ();
+}
+
 int main (int argc, char *argv[])
 {
     gint i;
     GDictApplet * applet = NULL;
     GnomeClient *client;
 
-    
-
-    static struct poptOption args[] = {
-        {"noapplet", 'a', POPT_ARG_NONE, 0, 0, "Startup without applet support", NULL},
-        {NULL, 0, 0, NULL, 0, NULL, NULL}
-    };
-
     bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
     textdomain(GETTEXT_PACKAGE);
 
-    gnome_init_with_popt_table ("gdict", VERSION, argc, argv,
-                                    args, 0, NULL);
+    gnome_program_init ("gnome-dictionary",VERSION,
+                                      LIBGNOMEUI_MODULE,
+                                      argc, argv,
+                                      GNOME_PARAM_APP_DATADIR,DATADIR,NULL);
 
-    if ((client = gnome_master_client()) != NULL)
-            gtk_signal_connect (GTK_OBJECT(client), "save_yourself",
-                                GTK_SIGNAL_FUNC(save_yourself_cb),
-				(gpointer) argv[0]);
+	
+
+    if ((client = gnome_master_client()) != NULL) {
+            g_signal_connect (client, "save_yourself",
+                              G_CALLBACK (save_yourself_cb),
+                              (gpointer) argv[0]);
+            g_signal_connect (client, "die", G_CALLBACK (client_die_cb), NULL);
+    }
     
     
     gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gdict.png");
