@@ -162,6 +162,7 @@ mon_edit_actions (GtkWidget *widget, gpointer data)
   gtk_signal_connect_object (GTK_OBJECT (button), "clicked",
 			     GTK_SIGNAL_FUNC (gtk_widget_destroy),
 			     GTK_OBJECT (actions_dialog));
+  gtk_widget_grab_focus (button);
   gtk_widget_show (button);
 
   button = gtk_button_new_from_stock (GNOME_STOCK_BUTTON_OK);
@@ -206,17 +207,20 @@ make_tree_from_actions_db (GList *db)
       if (strncmp (buffer, action->tag, 49) != 0) {
 	  strncpy (buffer, action->tag, 50);
 	  buffer[49] = '\0';
-	  /* this is the parent node */
+          /* Add an action with a new tag as a top level node(parent node) */  
           gtk_tree_store_append (ctree, &newiter, NULL);
           gtk_tree_store_set (ctree, &newiter, 0, buffer, 1,
                               (gpointer)action, -1);
           ctree_parent = gtk_tree_iter_copy (&newiter);
 	}
-      /* this is the actual node */
-      /* Store data in tree */
-      gtk_tree_store_append (ctree, &newiter, ctree_parent); 
-      gtk_tree_store_set (ctree, &newiter, 0, buffer, 1,
-                          (gpointer)action, -1);
+      else {
+          /* If Tag of new action is same as an existing action's tag, add 
+             the new action as a child to the existing action(parent) */
+
+	  gtk_tree_store_append (ctree, &newiter, ctree_parent); 
+	  gtk_tree_store_set (ctree, &newiter, 0, buffer, 1,
+			      (gpointer)action, -1);
+	}
     }
 
   /* done. */
@@ -589,10 +593,8 @@ apply_edit (GtkWidget *w, gpointer data)
 	edited_action->action =
 		gtk_editable_get_chars (GTK_EDITABLE (action), 0, -1);
 	g_free (edited_action->description);
-	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (description));
-	gtk_text_buffer_get_bounds (buffer, &start, &end);
 	edited_action->description =
-		gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
+		gtk_editable_get_chars (GTK_EDITABLE (description), 0, -1);
 
 	if ( ! g_list_find (local_actions_db, edited_action))
 		local_actions_db = g_list_prepend (local_actions_db,
@@ -747,6 +749,7 @@ edit_action_entry (Action *action)
   gtk_widget_set_usize (text, 200, -1);
   gtk_entry_set_editable (GTK_ENTRY (text), TRUE);
   gtk_box_pack_start (GTK_BOX (hbox), text, TRUE, TRUE, 0);
+  gtk_entry_set_text (GTK_ENTRY (text), action->description);
   gtk_tooltips_set_tip (tips, text, _("Description of this entry."), NULL);
   gtk_widget_show (text); 
   gtk_object_set_data (GTK_OBJECT (action_record), "description", text);
@@ -776,12 +779,6 @@ edit_action_entry (Action *action)
 
 
   gtk_widget_show (action_record);
-
-  /* Insert text into text widget */
-  if (action->description)
-     gtk_text_buffer_set_text (gtk_text_view_get_buffer(GTK_TEXT_VIEW (text)),
-  			       action->description, 
-	  		       strlen (action->description));
 }
 
 /* ----------------------------------------------------------------------
