@@ -427,7 +427,7 @@ log_repaint (GtkWidget * win, GdkEventExpose * event)
       log_layout = gtk_widget_create_pango_layout (main_win_scrollbar, "");
       context = gdk_pango_context_get ();
       pango_context_set_language (context, gtk_get_default_language ());
-      font = pango_context_load_font (context, cfg->fixedb);
+      font = LoadFont (context, cfg->fixedb);
       metrics = pango_font_get_metrics
                 (font, pango_context_get_language (context));
       canvas = win->window;
@@ -505,6 +505,7 @@ UpdateStatusArea ()
 {
   struct tm *tdm;
   char status_text[255];
+  char *utf8;
   char *buffer;
   /* Translators: Date only format, %x should well do really */
   const char *time_fmt = _("%x"); /* an evil way to avoid warning */
@@ -528,15 +529,20 @@ UpdateStatusArea ()
 
   if (strftime (status_text, sizeof (status_text), time_fmt, tdm) <= 0) {
 	  /* as a backup print in US style */
-	  g_snprintf (status_text, sizeof (status_text), "%02d/%02d/%02d", 
-		      tdm->tm_mday, tdm->tm_mon, tdm->tm_year % 100);
+	  utf8 = g_strdup_printf ("%02d/%02d/%02d", 
+				  tdm->tm_mday, tdm->tm_mon,
+				  tdm->tm_year % 100);
+  } else {
+	  utf8 = LocaleToUTF8 (status_text);
   }
   gtk_label_get ( date_label, (char **)&buffer);
 /* FIXME: is this if statement needed?  would it make sense 
    to set the text every time?  doesn't gtk test for it in 
    a more efficient manner? */
-   if (strcmp (status_text, buffer) != 0)
-    gtk_label_set_text (date_label, status_text);
+   if (strcmp (utf8, buffer) != 0)
+	   gtk_label_set_text (date_label, utf8);
+
+   g_free (utf8);
 }
 
 /* ----------------------------------------------------------------------
@@ -603,7 +609,8 @@ log_redrawcursor (int ol, int nl, Page * np)
 void
 DrawLogLine (LogLine *line, int y)
 {
-  char tmp[1024];
+  char tmp[4096];
+  char *utf8;
   int num_chars, max_num_chars;
   int col_pos = 0;
   int char_width;
@@ -630,18 +637,22 @@ DrawLogLine (LogLine *line, int y)
 	  /* Translators: should be only the time, date could be bogus */
 	  if (strftime (tmp, sizeof (tmp), _("%X"), &date) <= 0) {
 		  /* as a backup print in 24 hours style */
-		  g_snprintf (tmp, sizeof (tmp), "%02d:%02d:%02d", line->hour, line->min, line->sec);
+		  utf8 = g_strdup_printf ("%02d:%02d:%02d", line->hour, line->min, line->sec);
+	  } else {
+		  utf8 = LocaleToUTF8 (tmp);
 	  }
 
   } else {
-	  strcpy (tmp, " ");
+	  utf8 = g_strdup (" ");
   }
   pango_layout_set_font_description (log_layout, cfg->fixed);
-  pango_layout_set_text (log_layout, tmp, -1);
+  pango_layout_set_text (log_layout, utf8, -1);
   gdk_draw_layout (canvas, gc, LOG_COL1, y-10, log_layout);
 
   /* Print four spaces */
-  col_pos = LOG_COL1 + strlen(tmp)*char_width;
+  col_pos = LOG_COL1 + g_utf8_strlen(utf8, 1023)*char_width;
+  g_free (utf8);
+
   strcpy (tmp, "    ");
   pango_layout_set_text (log_layout, tmp, -1);
   gdk_draw_layout (canvas, gc, col_pos, y-10, log_layout);
@@ -650,9 +661,10 @@ DrawLogLine (LogLine *line, int y)
   strcpy (tmp, " ");
   if(user_prefs->hostname_column_width > 0)
   {
-  	g_snprintf (tmp, sizeof (tmp), "%s", line->hostname);
-  	if (strlen (tmp) > user_prefs->hostname_column_width)
-    		tmp[user_prefs->hostname_column_width+1] = '\0';
+	  utf8 = LocaleToUTF8 (line->hostname);
+	  /* FIXME: check we really do have enough room in tmp, we should */
+	  g_utf8_strncpy (tmp, utf8, user_prefs->hostname_column_width);
+	  g_free (utf8);
   }
   pango_layout_set_text (log_layout, tmp, -1);
   pango_layout_set_font_description (log_layout, cfg->fixed);
@@ -669,9 +681,10 @@ DrawLogLine (LogLine *line, int y)
   strcpy (tmp, " ");
   if(user_prefs->process_column_width > 0)
   {
-  	g_snprintf (tmp, sizeof (tmp), "%s", line->process);
-  	if (strlen (tmp) > user_prefs->process_column_width)
-    		tmp[user_prefs->process_column_width+1] = '\0';
+	  utf8 = LocaleToUTF8 (line->process);
+	  /* FIXME: check we really do have enough room in tmp, we should */
+	  g_utf8_strncpy (tmp, utf8, user_prefs->process_column_width);
+	  g_free (utf8);
   }
   pango_layout_set_text (log_layout, tmp, -1);
   pango_layout_set_font_description (log_layout, cfg->fixed);
@@ -687,12 +700,13 @@ DrawLogLine (LogLine *line, int y)
 
   /* For now max string length is ignored */
   num_chars = MAX (strlen (line->message), 1023);
-  tmp[1023] = '\0';
-  strncpy (tmp, line->message, 1023);
   max_num_chars = (canvas_width - 10 - col_pos) / char_width;
   if (max_num_chars < num_chars)
     max_num_chars = num_chars;
-  tmp[max_num_chars] = '\0';
+  utf8 = LocaleToUTF8 (line->message);
+  /* FIXME: check we really do have enough room in tmp, we should */
+  g_utf8_strncpy (tmp, utf8, max_num_chars);
+  g_free (utf8);
   pango_layout_set_text (log_layout, tmp, -1);
   pango_layout_set_font_description (log_layout, cfg->fixed);
   gdk_draw_layout (canvas, gc, col_pos, y-10, log_layout);
@@ -707,7 +721,8 @@ DrawLogLine (LogLine *line, int y)
 void
 DrawMonthHeader (LogLine * line, int y)
 {
-   char buf[100];
+   char buf[256];
+   char *utf8;
    int  h, centery, skip;
    GdkColor color[3];
    PangoContext *context;
@@ -720,12 +735,12 @@ DrawMonthHeader (LogLine * line, int y)
 
    context = gdk_pango_context_get ();
    pango_context_set_language (context, gtk_get_default_language ());
-   font = pango_context_load_font (context, cfg->headingb);
+   font = LoadFont (context, cfg->headingb);
    metrics = pango_font_get_metrics
 	     (font, pango_context_get_language (context));
    h = PANGO_PIXELS (pango_font_metrics_get_ascent (metrics)) -
        PANGO_PIXELS (pango_font_metrics_get_descent (metrics));
-   font = pango_context_load_font (context, cfg->fixed);	
+   font = LoadFont (context, cfg->fixed);	
    metrics = pango_font_get_metrics
 	     (font, pango_context_get_language (context));
    skip = (log_line_sep - PANGO_PIXELS (pango_font_metrics_get_ascent (metrics))
@@ -735,25 +750,32 @@ DrawMonthHeader (LogLine * line, int y)
 
    gdk_gc_set_foreground (gc, &cfg->black);
    if (line->month >= 0 && line->month < 12) {
-	   GDate *date = g_date_new_dmy (line->date, line->month+1, 2000 /* bogus */);
+	   struct tm tm = {0};
+
+	   tm.tm_mday = line->date;
+	   tm.tm_year = 2000 /* bogus */;
+	   tm.tm_mon = line->month;
 	   /* Translators: Make sure this is only Month and Day format, year
 	    * will be bogus here */
-	   if (g_date_strftime (buf, sizeof (buf), _("%B %e"), date) <= 0) {
+	   if (strftime (buf, sizeof (buf), _("%B %e"), &tm) <= 0) {
 		   /* If we fail just use the US format */
-		   g_snprintf (buf, sizeof (buf), "%s %d", _(month[(int) line->month]), line->date);
+		   utf8 = g_strdup_printf ("%s %d", _(month[(int) line->month]), line->date);
+	   } else {
+		   utf8 = LocaleToUTF8 (buf);
 	   }
-	   g_date_free (date);
    } else {
-	   g_snprintf (buf, sizeof (buf), "?%d? %d", (int) line->month, line->date);
+	   utf8 = g_strdup_printf ("?%d? %d", (int) line->month, line->date);
    }
-   pango_layout_set_text (log_layout, buf, -1);
+   pango_layout_set_text (log_layout, utf8, -1);
    pango_layout_set_font_description (log_layout, cfg->headingb);
    gdk_draw_layout (canvas, gc, LOG_COL1 - 1, centery + 1 - 12, log_layout);
    gdk_gc_set_foreground (gc, &cfg->white);
-   pango_layout_set_text (log_layout, buf, -1);
+   pango_layout_set_text (log_layout, utf8, -1);
    pango_layout_set_font_description (log_layout, cfg->headingb);
    gdk_draw_layout (canvas, gc, LOG_COL1, centery -12, log_layout);
 
+   g_free (utf8);
+
    g_object_unref (G_OBJECT (font));
    pango_font_metrics_unref (metrics);
    g_object_unref (G_OBJECT (context));
